@@ -13,7 +13,7 @@ def get_mapped_commands() -> dict:
 class Command(object):
 
     def __init__(self, function_name: str, args: list,
-                 kwargs: dict, attrs: list = None, exec_fn: Callable = None):
+                 kwargs: dict, attrs: list = [], exec_fn: Callable = None):
         self.function_name = function_name
         self.args = args
         self.kwargs = kwargs
@@ -22,6 +22,6 @@ class Command(object):
 
     def execute_routine(self):
         if self.exec_fn is None:
-            raise TranslationMissing()
+            raise TranslationMissing(self.name)
 
         return self.exec_fn(*self.args, **self.kwargs)
